@@ -4,13 +4,12 @@ py.test and pylib: rapid testing and development utils
 this module uses apipkg.py for lazy-loading sub modules
 and classes.  The initpkg-dictionary  below specifies
 name->value mappings where value can be another namespace
-dictionary or an import path.  
+dictionary or an import path.
 
 (c) Holger Krekel and others, 2004-2010
 """
-version = "1.2.1"
+__version__ = version = "1.3.4"
 
-__version__ = version = version or "1.2.x"
 import py.apipkg
 
 py.apipkg.initpkg(__name__, dict(
@@ -26,7 +25,6 @@ py.apipkg.initpkg(__name__, dict(
         'pytest':     '._cmdline.pytest:main',
         'pylookup':   '._cmdline.pylookup:main',
         'pycountloc': '._cmdline.pycountlog:main',
-        'pytest':     '._test.cmdline:main',
         'pylookup':   '._cmdline.pylookup:main',
         'pycountloc': '._cmdline.pycountloc:main',
         'pycleanup':  '._cmdline.pycleanup:main',
@@ -39,11 +37,6 @@ py.apipkg.initpkg(__name__, dict(
         # helpers for use from test functions or collectors
         '__onfirstaccess__' : '._test.config:onpytestaccess',
         '__doc__'           : '._test:__doc__',
-        'raises'            : '._test.outcome:raises',
-        'skip'              : '._test.outcome:skip',
-        'importorskip'      : '._test.outcome:importorskip',
-        'fail'              : '._test.outcome:fail',
-        'exit'              : '._test.outcome:exit',
         # configuration/initialization related test api
         'config'            : '._test.config:config_per_process',
         'ensuretemp'        : '._test.config:ensuretemp',
@@ -104,6 +97,8 @@ py.apipkg.initpkg(__name__, dict(
         'patch_builtins'    : '._code.code:patch_builtins',
         'unpatch_builtins'  : '._code.code:unpatch_builtins',
         '_AssertionError'   : '._code.assertion:AssertionError',
+        '_reinterpret_old'  : '._code.assertion:reinterpret_old',
+        '_reinterpret'      : '._code.assertion:reinterpret',
     },
 
     # backports and additions of builtins
@@ -116,6 +111,7 @@ py.apipkg.initpkg(__name__, dict(
         'frozenset'      : '._builtin:frozenset',
         'BaseException'  : '._builtin:BaseException',
         'GeneratorExit'  : '._builtin:GeneratorExit',
+        '_sysex'         : '._builtin:_sysex',
         'print_'         : '._builtin:print_',
         '_reraise'       : '._builtin:_reraise',
         '_tryimport'     : '._builtin:_tryimport',
@@ -126,6 +122,7 @@ py.apipkg.initpkg(__name__, dict(
         '_istext'        : '._builtin:_istext',
         '_getimself'     : '._builtin:_getimself',
         '_getfuncdict'   : '._builtin:_getfuncdict',
+        '_getcode'       : '._builtin:_getcode',
         'builtins'       : '._builtin:builtins',
         'execfile'       : '._builtin:execfile',
         'callable'       : '._builtin:callable',
@@ -141,6 +138,9 @@ py.apipkg.initpkg(__name__, dict(
         'StdCapture'          : '._io.capture:StdCapture',
         'StdCaptureFD'        : '._io.capture:StdCaptureFD',
         'TerminalWriter'      : '._io.terminalwriter:TerminalWriter',
+        'ansi_print'          : '._io.terminalwriter:ansi_print',
+        'get_terminal_width'  : '._io.terminalwriter:get_terminal_width',
+        'saferepr'            : '._io.saferepr:saferepr',
     },
 
     # small and mean xml/html generation
